@@ -7,8 +7,8 @@ httpget_session <- function(filepath, requri){
   setwd(filepath);
   
   #reqhead is package api
-  reqhead <- head(requri, 1);
-  reqtail <- tail(requri, -1);    
+  reqhead <- utils::head(requri, 1);
+  reqtail <- utils::tail(requri, -1);    
   
   #list the session contents
   if(!length(reqhead)){
