@@ -2,10 +2,10 @@ httpget_session_zip <- function(sessionpath, requri){
   setwd(sessionpath);
   allfiles <- list.files(all.files=TRUE, recursive=TRUE);
   tmpzip <- tempfile(fileext=".zip");
-  zip(tmpzip, files=allfiles);
+  utils::zip(tmpzip, files=allfiles);
   
   #debug 
-  stoponwarn(unzip(tmpzip));
+  stoponwarn(utils::unzip(tmpzip));
   
   #continue
   res$setbody(file=tmpzip);
